@@ -7,11 +7,6 @@ Version module for tpDcc-libs-curves
 
 from __future__ import print_function, division, absolute_import
 
-__author__ = "Tomas Poveda"
-__license__ = "MIT"
-__maintainer__ = "Tomas Poveda"
-__email__ = "tpovedatd@gmail.com"
-
 __version__ = None
 
 
